#!/usr/bin/env python
# vim: sts=4 sw=4 et

import sys, time
import hal, emc

class FixedJog:
    def __init__(self, max_axis = 9):
        self.comp = hal.component('fixed-jog')
        self.emc = emc.command()

        self.comp.newpin("step", hal.HAL_FLOAT, hal.HAL_IN)
        self.comp.newpin("speed", hal.HAL_FLOAT, hal.HAL_IN)
        for a in range(max_axis):
            self.comp.newpin("%d" % a, hal.HAL_BIT, hal.HAL_IN)
            self.comp.newpin("%d.reverse" % a, hal.HAL_BIT, hal.HAL_IN)
        self.watch = range(max_axis)

    def exit(self):
        self.comp.exit()

    def update(self):
        all_step = self.comp['step']
        speed = self.comp['speed']
        for a in self.watch:
            step = all_step
            if not step or not speed:
                continue
            trigger = self.comp['%d' % a]
            reverse = self.comp['%d.reverse' % a]
            if reverse:
                step = -step
            if trigger:
                #print "%d: %f %f" % (a, step, speed)
                self.emc.jog(emc.JOG_INCREMENT, a, speed, step)
                break
        else:
            return
        for a in range(10):
            #print "Waiting"
            if self.emc.wait_complete() > 0:
                return

if __name__ == '__main__':
    jog = FixedJog()
    try:
        while True:
            jog.update()
            time.sleep(0.1)
    finally:
        jog.exit()
